import { StyleSheet } from 'react-native'

export default StyleSheet.create({
  hyperlink: {
    color: '#0000EE'
  }
})
